@@ -1,7 +1,9 @@
+import os
 from collections import defaultdict
 
 import numpy as np
-from prettytable import PrettyTable
+import pandas as pd
+from prettytable import PrettyTable, from_csv
 
 """
     For record your machine learning process and export it as a table.
@@ -75,11 +77,26 @@ class Recorder:
         result = defaultdict(dict)
         self.table = PrettyTable()
         assert len(self.Item_dict) >= 1, "no data, process nothing!"
+        keyset = set()
         for item in self.Item_dict:
             result[item] = self.Item_dict[item].process(process_type)
-        self.table.add_column('', list(result[item].keys()))
+            keyset = set.union(keyset, set(result[item].keys()))
+        for item in self.Item_dict:
+            for key in keyset:
+                if key not in result[item].keys():
+                    result[item][key] = "Null"
+
+        self.table.add_column(self.table_name, list(result[item].keys()))
         for col in result:
             self.table.add_column(col, list(result[col].values()))
+        if len(keyset) >= 5:
+            self.store_csv('tmp.csv')
+            frame = pd.read_csv('tmp.csv', index_col=self.table_name)
+            frame = frame.transpose()
+            frame.to_csv('tmp.csv')
+            with open('tmp.csv', 'r+') as f:
+                self.table = from_csv(f)
+            os.remove('tmp.csv')
 
     def store_csv(self, file_path='recorder.csv') -> None:
         with open(file_path, 'w+') as f:
@@ -88,11 +105,4 @@ class Recorder:
 
 
 if __name__ == '__main__':
-    recorder = Recorder(table_name='test')
-    for i in range(3):
-        for j in range(5):
-            for k in range(100):
-                recorder.record(f'col{i}', f'row{j}', k * i + 1)
-    recorder.process(process_type={'row0': 'mean', 'row1': 'max', 'row2': 'min', 'row3': 'std', 'row4': 'median'})
-    print(recorder)
-    recorder.store_csv()
+    print("hhh")
